==> 1.0.9.tar.gz: android/src/main/java/com/fusion/fusionsdk/FusionFlutterPlugin.java <==
package com.fusion.fusionsdk;

import android.app.Activity;

import androidx.annotation.NonNull;
import androidx.core.util.Consumer;


import com.fusion.fusionsdk.utils.AdUtils;
import com.fusion.fusionsdk.utils.Constants;

import io.flutter.app.FlutterApplication;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * FusionFlutterPlugin
 */
public class FusionFlutterPlugin implements FlutterPlugin, ActivityAware, MethodCallHandler {

    private FlutterApplication flutterApplication;
    private BinaryMessenger binaryMessenger;
    private Activity activity;
    private MethodChannel channel;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        flutterApplication = (FlutterApplication) flutterPluginBinding.getApplicationContext();
        binaryMessenger = flutterPluginBinding.getBinaryMessenger();
        channel = new MethodChannel(binaryMessenger, Constants.METHOD);
        channel.setMethodCallHandler(this);

        flutterPluginBinding.getPlatformViewRegistry().registerViewFactory(Constants.VIEW_TYPE, new FusionAdViewFactory(binaryMessenger));
    }

    @Override
    public void onMethodCall(@NonNull final MethodCall call, @NonNull Result result) {

        switch (call.method) {
            case Constants.METHOD_LOAD_REWARD_VIDEO:
                callMethod(call.argument(Constants.EVENT_ID), c -> AdUtils.loadRewardVideo(activity, call.argument(Constants.CODE_ID), call.argument(Constants.USER_ID),call.argument(Constants.EXT), c));
                break;
            case Constants.METHOD_LOAD_INTERSTITIAL:
                callMethod(call.argument(Constants.EVENT_ID), c -> AdUtils.loadInterstitialAd(activity, call.argument(Constants.CODE_ID), c));
                break;
        }
    }

    private void callMethod(Integer eventId, final Consumer<EventChannel.EventSink> consumer) {
        EventChannel eventChannel = new EventChannel(binaryMessenger, Constants.MESSAGE_EVENT + eventId);
        eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object o, EventChannel.EventSink eventSink) {
                consumer.accept(eventSink);
            }

            @Override
            public void onCancel(Object o) {
            }
        });
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        activity = binding.getActivity();
        flutterApplication.setCurrentActivity(activity);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        activity = null;
        flutterApplication.setCurrentActivity(null);
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }
}

==> 1.1.6.tar.gz: android/src/main/java/com/fusion/fusionsdk/FusionFlutterPlugin.java <==
package com.fusion.fusionsdk;

import android.app.Activity;

import androidx.annotation.NonNull;
import androidx.core.util.Consumer;


import com.fusion.fusionsdk.utils.AdUtils;
import com.fusion.fusionsdk.utils.Constants;

import io.flutter.app.FlutterApplication;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * FusionFlutterPlugin
 */
public class FusionFlutterPlugin implements FlutterPlugin, ActivityAware, MethodCallHandler {

    private FlutterApplication flutterApplication;
    private BinaryMessenger binaryMessenger;
    private Activity activity;
    private MethodChannel channel;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        flutterApplication = (FlutterApplication) flutterPluginBinding.getApplicationContext();
        binaryMessenger = flutterPluginBinding.getBinaryMessenger();
        channel = new MethodChannel(binaryMessenger, Constants.METHOD);
        channel.setMethodCallHandler(this);

        flutterPluginBinding.getPlatformViewRegistry().registerViewFactory(Constants.VIEW_TYPE, new FusionAdViewFactory(binaryMessenger));
    }

    @Override
    public void onMethodCall(@NonNull final MethodCall call, @NonNull Result result) {

        switch (call.method){
            case Constants.METHOD_LOAD_REWARD_VIDEO:
                callMethod(call.argument(Constants.EVENT_ID),c -> AdUtils.loadRewardVideo(activity,call.argument(Constants.CODE_ID),c));
                break;
            case Constants.METHOD_LOAD_INTERSTITIAL:
                callMethod(call.argument(Constants.EVENT_ID),c -> AdUtils.loadInterstitialAd(activity,call.argument(Constants.CODE_ID),c));
                break;
        }
    }

    private void callMethod(Integer eventId, final Consumer<EventChannel.EventSink> consumer) {
        EventChannel eventChannel = new EventChannel(binaryMessenger, Constants.MESSAGE_EVENT + eventId);
        eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object o, EventChannel.EventSink eventSink) {
                consumer.accept(eventSink);
            }

            @Override
            public void onCancel(Object o) {
            }
        });
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        activity = binding.getActivity();
        flutterApplication.setCurrentActivity(activity);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        activity = null;
        flutterApplication.setCurrentActivity(null);
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }
}
